function testTreeTable

%% Create a TreeTable

% Create a figure
HWIN = figure('menubar','none',...
    'numbertitle','off');

% Create a TreeTable
T = jacontrol(HWIN, 'style', 'treetable',...
    'units','normalized',...
    'callback',@treeCallback,...
    'position',[0 0 1 1]);

EXAMPLENR=1;
switch EXAMPLENR
    case 1
        %Example 1: display direcory structure
        dirNames=dirtree(pwd);
        parents=cell(size(dirNames));
        for k=1:length(dirNames)
            parents{k}=fileparts(dirNames{k});
        end
        [~,hierarchy]=ismember(char(parents),char(dirNames),'rows');
        N = length(dirNames);
        set(T,'data', dirNames,...
            'hierarchy',hierarchy,...
            'columnnames', {'Directory'});
    case 2
        % Set random data
        N = 12;
        L=false(N,1);
        L(1:floor(N/2))=true;
        set(T,'data', [repmat({''},N,1) num2cell(L) num2cell(1:N)' num2cell(.5 - rand(N,2))],...
            'hierarchy',[0 1 1 1 1 2 2 2 3 3 3 3],...
            'columnnames', {'Column 1','Column 2','Column 3', 'Column 4', 'Column 5'});
end

set(HWIN,'name','A TreeTable');

% Note if hierarchy looks like this:
% [0 1 1 1 1 2 2 2 3 3 3 3]
%  a b c d e f g h i j k l
% Rows will be displayed as follows
%     a
%     +--b
%        +--f
%        +--g
%        +--h
%     +--c
%        +--i
%        +--j
%        +--k
%        +--l
%     +--d
%     +--e


%% Expand all rows

set(T,'expandedrows', true(N,1));
set(HWIN,'name','An expanded TreeTable');

%% Change icons

set(T,'iconset', 'filetypes.jar');
set(T,'iconnames', {'bullet_green.gif';'bullet_red.gif';'bullet_grey.gif';'bullet_green.gif';'bullet_red.gif';'bullet_grey.gif';'bullet_green.gif';'bullet_red.gif';'bullet_grey.gif';'bullet_green.gif';'bullet_red.gif';'bullet_grey.gif';});
set(T,'expandedrows', true(N,1));

%% Specify renderers

set(T, 'columnformat', {'','','','absbar','bar'});
set(HWIN,'name','TreeTable with renderers');

%% Specify highlighter

set(T, 'highlighter', 'genericgrey');
set(HWIN,'name','TreeTable with highlighter');
 
%% Set infolabel and selectedrows

set(T, 'infolabel', true,...
    'selectedrows',[2]);
set(HWIN,'name','TreeTable with infolabel');

function treeCallback(obj,event)
%% Example info retrieved using metods of tree object and tree event
disp(sprintf('Selected row(s) (tree object): %d',obj.getSelectedRows))
disp(sprintf('Selected row (event object): %d',event.getSelectedRows))